pwhois: pwhois

Description Author(s) See Also

Description

WHOIS (pronounced as the phrase "who is") is a query and response protocol that is widely used for querying databases that store the registered users or assignees of an Internet resource, such as a domain name, an IP address block or an autonomous system, but is also used for a wider range of other information. The protocol stores and delivers database content in a human- readable format. The current iteration of the WHOIS protocol was drafted by the Internet Society, and is documented in RFC 3912. Tools are provided to issue query requests and process query responses.

Author(s)

Bob Rudis (bob@rud.is)

See Also

Useful links:


hrbrmstr/pwhois documentation built on April 26, 2021, 5:45 a.m.