tidy_cymru: Turn a Team Cymru server response into a data frame

Description Usage Arguments Value Examples

View source: R/tidy.R

Description

Turn a Team Cymru server response into a data frame

Usage

1
tidy_cymru(cymru_raw_response)

Arguments

cymru_raw_response

the raw response from a call to whois()

Value

data frame

Examples

1
2
res <- whois('type=cymru 17.253.144.10') # 'type=cymru' is only supported on pwhois
tidy_pwhois(res)

hrbrmstr/pwhois documentation built on April 26, 2021, 5:45 a.m.